CpmToken class

Annotations
  • @JsonSerializable.new()

Constructors

CpmToken({required String cpmToken, required Account account, UserTransactionWithTransfers? transaction, required List<String> scopes, required DateTime expiresAt, required Map<String, dynamic> metadata, String? strategy, String? couponId})
CpmToken.fromJson(Map<String, dynamic> json)
factory

Properties

account Account
final
couponId String?
final
cpmToken String
final
expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
strategy String?
final
transaction UserTransactionWithTransfers?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited