IndividualNumberIdentificationError class

Annotations
  • @JsonSerializable.new()

Constructors

IndividualNumberIdentificationError({required String type, required String message, required int errorCode, required String errorMessage})
IndividualNumberIdentificationError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode int
final
errorMessage String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited