Terminal class

Annotations
  • @JsonSerializable.new()

Constructors

Terminal({required String id, required String name, required String hardwareId, String? pushService, String? pushToken, required UserWithAuthFactors user, Account? account})
Terminal.fromJson(Map<String, dynamic> json)
factory

Properties

account Account?
final
hardwareId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
pushService String?
final
pushToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user UserWithAuthFactors
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited