UserTransfer class

Annotations
  • @JsonSerializable.new()

Constructors

UserTransfer({required String id, required String transactionId, required User user, required double balance, required double amount, required double moneyAmount, required double pointAmount, required Account account, required String description, required DateTime doneAt, required String type})
UserTransfer.fromJson(Map<String, dynamic> json)
factory

Properties

account Account
final
amount double
final
balance double
final
description String
final
doneAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
moneyAmount double
final
pointAmount double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String
final
type String
final
user User
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited