ExchangedToken class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ExchangedToken({required String accessToken, required String issuedTokenType, required String tokenType, int? expiresIn, String? scope, String? refreshToken})
-
ExchangedToken.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessToken → String
-
final
- expiresIn → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuedTokenType → String
-
final
- refreshToken → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String?
-
final
- tokenType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited