UserWithAuthFactors class

Annotations
  • @JsonSerializable.new()

Constructors

UserWithAuthFactors({required String id, required String name, bool? isMerchant, String? tel, String? email, required bool isPasswordRegistered})
UserWithAuthFactors.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isMerchant bool?
final
isPasswordRegistered bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tel String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited