Account class
- Annotations
-
- @JsonSerializable.new()
Constructors
- Account({required String id, required String name, required double balance, required double moneyBalance, required double pointBalance, required double pointDebt, required bool isSuspended, required String status, required PrivateMoney privateMoney})
-
Account.fromJson(Map<
String, dynamic> json) -
factory
Properties
- balance → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isSuspended → bool
-
final
- moneyBalance → double
-
final
- name → String
-
final
- pointBalance → double
-
final
- pointDebt → double
-
final
- privateMoney → PrivateMoney
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited