CvsAuthorization class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CvsAuthorization({required String id, required String serviceOptionType, required int amount, required String name1, required String name2, required String tel, required DateTime payLimit, required Account account, required String haraikomiUrl, required String receiptNo, DateTime? doneAt, DateTime? canceledAt})
-
CvsAuthorization.fromJson(Map<
String, dynamic> json) -
factory
Properties
- account → Account
-
final
- amount → int
-
final
- canceledAt → DateTime?
-
final
- doneAt → DateTime?
-
final
- haraikomiUrl → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name1 → String
-
final
- name2 → String
-
final
- payLimit → DateTime
-
final
- receiptNo → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceOptionType → String
-
final
- tel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited