PokepayOAuthAPI class
Properties
-
env
→ APIEnv
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exchangeAuthCode({required String code, required String clientId, required String clientSecret, String grantType = "authorization_code"})
→ Future<AccessToken>
-
-
exchangeDelegationCode({required String code, required String clientId, required String clientSecret, String grantType = "urn:pokepay:delegation-code"})
→ Future<AccessToken>
-
-
exchangeToken({required String clientId, required String clientSecret, String? resource, String? audience, required String subjectToken, required String subjectTokenType, String? requestedTokenType, List<String>? scopes, String? actorTokenType, String? actorToken})
→ Future<ExchangedToken>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshAccessToken({required String refreshToken, required String clientId, required String clientSecret, String grantType = "refresh_token"})
→ Future<AccessToken>
-
-
toString()
→ String
-
A string representation of this object.
inherited